nxp-pac

Crates

git

Versions

mimxrt1064

Flavors

Atstmp

Struct Atstmp 

#[repr(transparent)]
pub struct Atstmp(pub u32);
Timestamp of Last Transmitted Frame

Tuple Fields

0: u32

Implementations

Source

impl Atstmp

pub const fn timestamp(&self) -> u32

Timestamp of the last frame transmitted by the core that had TxBD[TS] set the ff_tx_ts_frm signal asserted from the user application

pub const fn set_timestamp(&mut self, val: u32)

Timestamp of the last frame transmitted by the core that had TxBD[TS] set the ff_tx_ts_frm signal asserted from the user application