#[repr(transparent)]pub struct Galr(pub u32);Expand description
Descriptor Group Lower Address Register
Tuple Fields
0: u32Implementations
Sourceimpl Galr
impl Galr
Sourcepub const fn gaddr2(&self) -> u32
pub const fn gaddr2(&self) -> u32
Contains the lower 32 bits of the 64-bit hash table used in the address recognition process for receive frames with a multicast address
Sourcepub const fn set_gaddr2(&mut self, val: u32)
pub const fn set_gaddr2(&mut self, val: u32)
Contains the lower 32 bits of the 64-bit hash table used in the address recognition process for receive frames with a multicast address