nxp-pac

Crates

git

Versions

mimxrt1064

Flavors

Ialr

Struct Ialr 

#[repr(transparent)]
pub struct Ialr(pub u32);
Descriptor Individual Lower Address Register

Tuple Fields

0: u32

Implementations

Source

impl Ialr

pub const fn iaddr2(&self) -> u32

Contains the lower 32 bits of the 64-bit hash table used in the address recognition process for receive frames with a unicast address

pub const fn set_iaddr2(&mut self, val: u32)

Contains the lower 32 bits of the 64-bit hash table used in the address recognition process for receive frames with a unicast address