nxp-pac

Crates

git

Versions

mimxrt1064

Flavors

Iaur

Struct Iaur 

#[repr(transparent)]
pub struct Iaur(pub u32);
Descriptor Individual Upper Address Register

Tuple Fields

0: u32

Implementations

Source

impl Iaur

pub const fn iaddr1(&self) -> u32

Contains the upper 32 bits of the 64-bit hash table used in the address recognition process for receive frames with a unicast address

pub const fn set_iaddr1(&mut self, val: u32)

Contains the upper 32 bits of the 64-bit hash table used in the address recognition process for receive frames with a unicast address