nxp-pac

Crates

git

Versions

mimxrt1064

Flavors

Tdsr

Struct Tdsr 

#[repr(transparent)]
pub struct Tdsr(pub u32);
Transmit Buffer Descriptor Ring 0 Start Register

Tuple Fields

0: u32

Implementations

Source

impl Tdsr

pub const fn x_des_start(&self) -> u32

Pointer to the beginning of the transmit buffer descriptor queue.

pub const fn set_x_des_start(&mut self, val: u32)

Pointer to the beginning of the transmit buffer descriptor queue.