#[repr(transparent)]pub struct Atstmp(pub u32);Expand description
Timestamp of Last Transmitted Frame
Tuple Fields
0: u32Implementations
Sourceimpl Atstmp
impl Atstmp
Sourcepub const fn timestamp(&self) -> u32
pub const fn timestamp(&self) -> u32
Timestamp of the last frame transmitted by the core that had TxBD[TS] set the ff_tx_ts_frm signal asserted from the user application
Sourcepub const fn set_timestamp(&mut self, val: u32)
pub const fn set_timestamp(&mut self, val: u32)
Timestamp of the last frame transmitted by the core that had TxBD[TS] set the ff_tx_ts_frm signal asserted from the user application