#[repr(transparent)]pub struct Ialr(pub u32);Expand description
Descriptor Individual Lower Address Register
Tuple Fields
0: u32Implementations
Sourceimpl Ialr
impl Ialr
Sourcepub const fn iaddr2(&self) -> u32
pub const fn iaddr2(&self) -> u32
Contains the lower 32 bits of the 64-bit hash table used in the address recognition process for receive frames with a unicast address
Sourcepub const fn set_iaddr2(&mut self, val: u32)
pub const fn set_iaddr2(&mut self, val: u32)
Contains the lower 32 bits of the 64-bit hash table used in the address recognition process for receive frames with a unicast address