#[repr(transparent)]pub struct Iaur(pub u32);Expand description
Descriptor Individual Upper Address Register
Tuple Fields
0: u32Implementations
Sourceimpl Iaur
impl Iaur
Sourcepub const fn iaddr1(&self) -> u32
pub const fn iaddr1(&self) -> u32
Contains the upper 32 bits of the 64-bit hash table used in the address recognition process for receive frames with a unicast address
Sourcepub const fn set_iaddr1(&mut self, val: u32)
pub const fn set_iaddr1(&mut self, val: u32)
Contains the upper 32 bits of the 64-bit hash table used in the address recognition process for receive frames with a unicast address