#[repr(transparent)]pub struct Tdsr(pub u32);Expand description
Transmit Buffer Descriptor Ring 0 Start Register
Tuple Fields
0: u32Implementations
Sourceimpl Tdsr
impl Tdsr
Sourcepub const fn x_des_start(&self) -> u32
pub const fn x_des_start(&self) -> u32
Pointer to the beginning of the transmit buffer descriptor queue.
Sourcepub const fn set_x_des_start(&mut self, val: u32)
pub const fn set_x_des_start(&mut self, val: u32)
Pointer to the beginning of the transmit buffer descriptor queue.